@@ -203,6 +203,22 @@ def mask_where_too_few_values(Nmin, N, x):
     return N, x
 #--- End: def
 
+def double_precision(a):
+    '''
+'''
+    if a.dtype.kind == 'f':
+        newtype = float
+    elif a.dtype.kind == 'i':
+        newtype = int
+
+    if numpy_ma_isMA(a):
+        a = a.astype(newtype)
+    else:
+        a = a.astype(newtype, copy=False)
+
+    return a
+#--- End: def
+
 #---------------------------------------------------------------------
 # Maximum
 #---------------------------------------------------------------------
@@ -350,6 +366,8 @@ The weighted average along the specified axes.
         3-tuple.
 
 '''
+    a = double_precision(a)
+
     if masked:
         average = numpy_ma_average
     else:
@@ -395,8 +413,7 @@ def mean_fpartial(out, out1=None):
 def mean_ffinalise(out, sub_samples=None):
     '''
 
-    sub_samples: optional
-        Ignored.
+    sub_samples: `bool`, optional
 
 :Returns:
 
@@ -485,6 +502,8 @@ def mid_range_ffinalise(out, sub_samples=None):
 
 '''
     N, amin, amax = out
+
+    amax = double_precision(amax)
     
     # Cast bool, unsigned int, and int to float64
     if issubclass(amax.dtype.type, (numpy_integer, numpy_bool_)):
@@ -515,7 +534,9 @@ Absolute difference between maximum and minimum
 
 '''
     N, amin, amax = out
-  
+
+    amax = double_precision(amax)
+
     amax -= amin
       
     return mask_where_too_few_values(1, N, amax)
@@ -612,6 +633,8 @@ axis=axis),)``
         2-tuple
 
 '''
+    a = double_precision(a)
+
     N    = sample_size_f(a, axis=axis, masked=masked)
     asum = a.sum(axis=axis)
 
@@ -653,6 +676,8 @@ def sw_f(a, axis=None, masked=False, weights=None):
     N = sample_size_f(a, axis=axis, masked=masked)
 
     if weights is not None:
+        weights = double_precision(weights)
+
         if weights.ndim < a.ndim:
             weights = broadcast_array(weights, a.shape)
 
@@ -680,6 +705,8 @@ def sw2_f(a, axis=None, masked=False, weights=None):
     N = sample_size_f(a, axis=axis, masked=masked)
 
     if weights is not None:
+        weights = double_precision(weights)
+
         if weights.ndim < a.ndim:
             weights = broadcast_array(weights, a.shape)
             
@@ -708,6 +735,8 @@ def var_f(a, axis=None, weights=None, masked=False, ddof=1, f=None):
     out: 8-`tuple` of `numpy.ndarray`
 
 ''' 
+    a = double_precision(a)
+
     # ----------------------------------------------------------------
     # Find the minimum and maximum values of the weights if required
     # ----------------------------------------------------------------
@@ -807,6 +836,16 @@ def var_fpartial(out, out1=None):
 
 def var_ffinalise(out, sub_samples=None):
     '''
+:Parameters:
+
+    out: 8-tuple of `numpy.ndarray`
+
+    sub_samples: `bool`, optional
+
+:Returns:
+
+    out: 2-tuple of `numpy.ndarray`
+
     '''
     N, var, avg, sw, ddof, f, wmin, wmax = out
 
@@ -836,7 +875,6 @@ def var_ffinalise(out, sub_samples=None):
     # ----------------------------------------------------------------
     # var is now the global variance with sw degrees of freedom
     # ----------------------------------------------------------------
-
     if ddof:
         if f:
             sw *= f
@@ -871,6 +909,7 @@ def var_ffinalise(out, sub_samples=None):
                    ccc &= numpy.isclose(nwmax, nwmax.astype(int), rtol=1e-05, atol=1e-08)
                    ccc &= numpy.isclose(nsw  , nsw.astype(int)  , rtol=1e-05, atol=1e-08)
                    m = numpy_where(ccc, n, m)
+                   print 'rase', m.min()
                    if m.min():
                        # Every element of m has been set (to an integer
                        # greater than 1), so we are done.
@@ -908,16 +947,16 @@ def sd_ffinalise(out, sub_samples=None):
 
 :Parameters:
 
-    out : tuple
+    out: `tuple`
         A 2-tuple
 
-    sub_samples : *optional*
+    sub_samples: *optional*
         Ignored.
 
 
 '''
     N, sd = var_ffinalise(out, sub_samples)
-    
+
     sd **= 0.5
     
     return N, sd
