@@ -5,7 +5,7 @@ from numpy import where as numpy_where
 from numpy import sum as numpy_sum
 from .data.data import Data
 from .coordinate import DimensionCoordinate
-from .functions import REGRID_LOGGING
+from .functions import REGRID_LOGGING, FREE_MEMORY
 from . import _found_ESMF
 if _found_ESMF:
     try:
